<?php
if ( !defined( 'BPB_VERSION' ) ) exit;

/**
 * Adjust BP_User_Query
 * @since 1.0
 * @version 1.0
 */
function bpb_adjust_user_query( $data ) {
	if ( !is_user_logged_in() ) return;
	
	$_list = bpb_get_blocked_users( get_current_user_id() );
	if ( ! empty( $_list ) ) {
		$list = implode( ',', $_list );
		$data->query_vars_raw['exclude'] = $list;
		$data->query_vars['exclude'] = $list;
	}
}

/**
 * Adjust Total Count
 * @since 1.0
 * @version 1.0
 */
function bpb_adjust_total_count( $count ) {
	if ( !is_user_logged_in() ) return $count;
	$list = count( bpb_get_blocked_users( get_current_user_id() ) );
	if ( $list === 0 ) return $count;
	return $count-$list;
}

/**
 * Adjust Latest Update
 * @since 1.0
 * @version 1.0
 */
function bpb_adjust_latest_update( $update_content ) {
	if ( is_user_logged_in() ) {
		$list = bpb_get_blocked_users( bp_get_member_user_id() );
		if ( in_array( get_current_user_id(), $list ) ) return '';
	}
	
	return $update_content;
}

/**
 * Adjust Mentions
 * @since 1.0
 * @version 1.0
 */
function bpb_adjust_mentions( $content, $activity ) {
	// Are mentions disabled?
	if ( ! bp_activity_do_mentions() ) {
		return $content;
	}

	// Try to find mentions
	$usernames = bp_activity_find_mentions( $content );

	// My list
	$my_list = bpb_get_blocked_users( get_current_user_id() );

	// We have mentions!
	if ( ! empty( $usernames ) ) {
		// Replace @mention text with plain username to disable notifications
		foreach( (array) $usernames as $user_id => $username ) {
			// Get the mentioned users block list
			$list = bpb_get_blocked_users( $user_id );
			
			// Users that block us or users that we block needs to be stripped out to prevent notices
			if ( in_array( $activity->user_id, $list ) || in_array( $user_id, $my_list ) ) {
				$activity->content = preg_replace( '/(@' . $username . '\b)/', '#' . $username, $activity->content );
				$content = preg_replace( '/(@' . $username . '\b)/', '#' . $username, $content );
			}
		}
	}
	return $content;
}

/**
 * Block Activity View
 * If the user listed is blocking us, we will not be able to see
 * their activities.
 * @since 1.0
 * @version 1.0
 */
function bpb_remove_activity_if_blocked( $update_content ) {
	global $members_template;
	
	if ( !empty( $members_template->member->id ) )
		$user_id = $members_template->member->id;
	elseif ( bp_displayed_user_id() )
		$user_id = bp_displayed_user_id();

	$users_list = bpb_get_blocked_users( $user_id );
	if ( in_array( get_current_user_id(), $users_list ) && ! current_user_can( 'edit_users' ) )
		return '';

	return $update_content;
}

function bpb_adjust_activity() {
	global $activities_template;
	
	$user_id = bp_activity_user_id();
	$users_list = bpb_get_blocked_users( $user_id );
	if ( in_array( get_current_user_id(), $users_list ) && ! current_user_can( 'edit_users' ) )
		exit;
}
?>